@@ -21,19 +21,18 @@ __author__ = 'Matthias Kuhn'
 __date__ = 'January 2016'
 __copyright__ = '(C) 2016, Matthias Kuhn'
 
-
 import qgis  # NOQA switch sip api
 
 import os
 import yaml
 import nose2
-import gdal
 import shutil
 import glob
 import hashlib
 import tempfile
 import re
 
+from osgeo import gdal
 from osgeo.gdalconst import GA_ReadOnly
 from numpy import nan_to_num
 from copy import deepcopy
@@ -113,7 +112,7 @@ class AlgorithmsTest(object):
                 parameters[k] = p
 
         for r, p in list(defs['results'].items()):
-            if not 'in_place_result' in p or not p['in_place_result']:
+            if 'in_place_result' not in p or not p['in_place_result']:
                 parameters[r] = self.load_result_param(p)
 
         expectFailure = False
@@ -171,6 +170,12 @@ class AlgorithmsTest(object):
         try:
             if param['type'] in ('vector', 'raster', 'table'):
                 return self.load_layer(id, param).id()
+            elif param['type'] == 'vrtlayers':
+                vals = []
+                for p in param['params']:
+                    p['layer'] = self.load_layer(None, {'type': 'vector', 'name': p['layer']})
+                    vals.append(p)
+                return vals
             elif param['type'] == 'multi':
                 return [self.load_param(p) for p in param['params']]
             elif param['type'] == 'file':
@@ -178,7 +183,7 @@ class AlgorithmsTest(object):
             elif param['type'] == 'interpolation':
                 prefix = processingTestDataPath()
                 tmp = ''
-                for r in param['name'].split(';'):
+                for r in param['name'].split('::|::'):
                     v = r.split('::~::')
                     tmp += '{}::~::{}::~::{}::~::{};'.format(os.path.join(prefix, v[0]),
                                                              v[1], v[2], v[3])
@@ -252,6 +257,12 @@ class AlgorithmsTest(object):
             self.in_place_layers[id] = filepath
 
         if param['type'] in ('vector', 'table'):
+            gmlrex = r'\.gml\b'
+            if re.search(gmlrex, filepath, re.IGNORECASE):
+                # ewwwww - we have to force SRS detection for GML files, otherwise they'll be loaded
+                # with no srs
+                filepath += '|option:FORCE_SRS_DETECTION=YES'
+
             if filepath in self.vector_layer_params:
                 return self.vector_layer_params[filepath]
 
@@ -321,19 +332,26 @@ class AlgorithmsTest(object):
                     if isinstance(results[id], QgsMapLayer):
                         result_lyr = results[id]
                     else:
-                        result_lyr = QgsProcessingUtils.mapLayerFromString(results[id], context)
+                        string = results[id]
+
+                        gmlrex = r'\.gml\b'
+                        if re.search(gmlrex, string, re.IGNORECASE):
+                            # ewwwww - we have to force SRS detection for GML files, otherwise they'll be loaded
+                            # with no srs
+                            string += '|option:FORCE_SRS_DETECTION=YES'
+
+                        result_lyr = QgsProcessingUtils.mapLayerFromString(string, context)
                     self.assertTrue(result_lyr, results[id])
 
                 compare = expected_result.get('compare', {})
                 pk = expected_result.get('pk', None)
-                topo_equal_check = expected_result.get('topo_equal_check', False)
 
                 if len(expected_lyrs) == 1:
-                    self.assertLayersEqual(expected_lyrs[0], result_lyr, compare=compare, pk=pk, geometry={'topo_equal_check': topo_equal_check})
+                    self.assertLayersEqual(expected_lyrs[0], result_lyr, compare=compare, pk=pk)
                 else:
                     res = False
                     for l in expected_lyrs:
-                        if self.checkLayersEqual(l, result_lyr, compare=compare, pk=pk, geometry={'topo_equal_check': topo_equal_check}):
+                        if self.checkLayersEqual(l, result_lyr, compare=compare, pk=pk):
                             res = True
                             break
                     self.assertTrue(res, 'Could not find matching layer in expected results')
@@ -350,8 +368,17 @@ class AlgorithmsTest(object):
                 else:
                     self.assertEqual(strhash, expected_result['hash'])
             elif 'file' == expected_result['type']:
-                expected_filepath = self.filepath_from_param(expected_result)
                 result_filepath = results[id]
+                if isinstance(expected_result.get('name'), list):
+                    # test to see if any match expected
+                    for path in expected_result['name']:
+                        expected_filepath = self.filepath_from_param({'name': path})
+                        if self.checkFilesEqual(expected_filepath, result_filepath):
+                            break
+                    else:
+                        expected_filepath = self.filepath_from_param({'name': expected_result['name'][0]})
+                else:
+                    expected_filepath = self.filepath_from_param(expected_result)
 
                 self.assertFilesEqual(expected_filepath, result_filepath)
             elif 'directory' == expected_result['type']:
@@ -368,7 +395,6 @@ class AlgorithmsTest(object):
 
 
 class GenericAlgorithmsTest(unittest.TestCase):
-
     """
     General (non-provider specific) algorithm tests
     """
@@ -378,7 +404,6 @@ class GenericAlgorithmsTest(unittest.TestCase):
         start_app()
         from processing.core.Processing import Processing
         Processing.initialize()
-        QgsApplication.processingRegistry().addProvider(QgsNativeAlgorithms())
         cls.cleanup_paths = []
 
     @classmethod
